from django import forms
from django.contrib.contenttypes.models import ContentType
from django.utils.translation import gettext as _
import models

class MenuAdminForm(forms.ModelForm):

    object_id = forms.ChoiceField(label=_("Content Object"), 
        choices=(('','Choose a Content Type first'),))
    url = forms.CharField(label=_("URL"), required=False,
        widget=forms.TextInput(attrs={'disabled': 'disabled'}))

    class Meta:
        model = models.Menu
    
    def is_valid(self):
        """Adds the choices variable to object_id to provide field validation"""
        ct = ContentType.objects.get(pk=int(self.data['content_type']))
        try:
            self.fields['object_id'].choices = \
                ct.model_class().objects.all().values_list('pk', 'pk')
        except ct.model_class().DoesNotExist:
            raise forms.ValidationError(_("The selected object does not exist"))
        return super(MenuAdminForm, self).is_valid()

    def save(self, commit=True):
        return super(MenuAdminForm, self).save(commit)
    

